/**** CIMRESET.CMD ************************************************************/
/* Rexx command file to reset OS2CIM's accumulated connect time each month.   */
/* Connect time for each month will be recorded to a log file.                */
/* This command file could be run multiple times per day - it will only reset */
/* OS2CIM's connect time once each month.  It will NOT reset the connect time */
/* each time it is run. If the last reset date is in the current month, the   */
/* command file does nothing.  Otherwise, it logs the accumulated connect     */
/* time and resets OS2CIM's connect clock to the first of the current month.  */
/* This command file is designed for OS2CIM version 2.03.  It has not been    */
/* tested on any other version.  The command file will modify the file        */
/* OS2-CIM.INI.  Please make a backup copy of this file before using CIMRESET */
/* for the first time. Connect times will be recorded to the file             */
/* CompuServeUsage.txt located in the same directory as OS2-CIM.INI           */ 
/*                                                                            */
/* Author: Rick Eichhorn    73051.302@compuserve.com                          */    
/* Date: February 20, 1996                                                    */
/* FREELY DISTRIBUTE                                                          */
/* E-mail contructive comments.  Feel free to correct or improve this program */
/*                                                                            */
/* USAGE: CIMRESET   (no parms required)                                      */
/* Place this command file in your startup folder.  Set the working directory */
/* to wherever OS2-CIM.INI resides (probably C:\CSERVE\OS2-CIM).  Or, if you  */
/* seldom reboot, use this command file to start OS2CIM.  Add the command     */
/* 'OS2-CIM' to the end of this file (quotes required).  You also may want to */
/* put a shadow to CompuServeUsage.txt on your desktop.  This is the file     */
/* your usage log will be recorded in. The file will be updated only once     */
/* each month.  To see connect time for the current month, use the dialog     */
/* box in OS2CIM.                                                             */
/*                                                                            */
/* Modification History:                                                      */
/*    2/20/96   Version 1.0                                                   */
/******************************************************************************/

/* Set some initial values.  You could add a full path name to the files. */
LogFile = 'CompuServeUsage.txt'
InputFile = 'OS2-CIM.INI'

/* We need the util functions to read ini file */
call rxfuncadd sysloadfuncs, rexxutil, sysloadfuncs
call sysloadfuncs

/* Get the date we last reset our connect time */
LastResetDate = SysIni(InputFile, 'Access_Info', 'Since-Day')
If LastResetDate == 'ERROR:' Then Do
   /* We have an error.  Probably could not find the ini file */
   Say "Unable to read OS2-CIM.INI."
   Say "Make sure this rexx file references the proper directory."   
   exit 1
End

/* Make the reset date a uniform length by padding with zeros if needed */
/* Example CIM dates: '22426.' is Feb 24, 1996.  '110327.' is Nov 3, 1997 */
LastResetDate = Right(LastResetDate, 7, '0')

/* If the reset date is not in the current month, we need to take action */
/* We could compare the reset year too, but is it really worth the trouble? */
ResetMonth = SubStr(LastResetDate, 1, 2)
CurrentMonth = SubStr(Date('S'), 5, 2)
If ResetMonth \== CurrentMonth Then Do
   /* One last check before altering the ini file */
   If DataType(ResetMonth, 'N') \== 1 Then Do
      Say "Invalid characters in OS2-CIM.INI File."
      Exit 1
   End 

   Call InitMonthNames

   /* Check if we have a log file.  If not, we need to create one */
   If stream(LogFile, 'c', 'query exists') == "" Then Do
      Call LineOut LogFile, "CompuServe Connect Time by Month for OS2CIM"
      Call LineOut LogFile, ""
   End

   /* Get the reset year - CIM uses 1970 as the epoch */
   ResetYear = SubStr(LastResetDate, 5, 2) + 1970

   /* Get the accumulated connect time for the month in minutes */
   MonthlyTime = SysIni(InputFile, 'Access_Info', 'Accumulated-Time')
   MonthlyTime = SubStr(MonthlyTime, 1, Length(MonthlyTime) - 1)

   /* Write our info to the log file. */
   Hours = MonthlyTime%60
   Minutes = MonthlyTime//60
   Call LineOut LogFile, MonthName.ResetMonth  ResetYear  Hours "Hours,"  Minutes "Minutes"

   /* Reset the connect clock */
   /* We need to construct a CIM date string for the first of the current month */
   CurrentYear = SubStr(Date('S'), 1, 4) - 1970
   CIMDate = CurrentMonth || '01' || CurrentYear || '.'

   /* If we have a leading zero, lop it off.  The CIM reset button does not use one */
   CIMDate = Strip(CIMDate, 'L', 0)
   
   /* Write our date to the CIM ini file - 2/01/96 would be 20126. */
   SysIni(InputFile, 'Access_Info', 'Since-Day', CIMDate)

   /* Reset our since time to midnight */
   SysIni(InputFile, 'Access_Info', 'Since-Time', '0.')

   /* Reset our accumulated connect time to zero */
   SysIni(InputFile, 'Access_Info', 'Accumulated-Time', '0.')
End

/*'OS2-CIM'*/

/* Exit, Stage Left */
Exit

/*******************************************************************************/
InitMonthNames:
   MonthName.01 = 'Jan'
   MonthName.02 = 'Feb'
   MonthName.03 = 'Mar'
   MonthName.04 = 'Apr'
   MonthName.05 = 'May'
   MonthName.06 = 'Jun'
   MonthName.07 = 'Jul'
   MonthName.08 = 'Aug'
   MonthName.09 = 'Sep'
   MonthName.10 = 'Oct'
   MonthName.11 = 'Nov'
   MonthName.12 = 'Dec'
   return

/*******************************************************************************/
